#  Ebay (Videos, Music, Files)
#
# @website     https://www.ebay.com
# @provide-api no (nothing found)
#
# @using-api   no
# @results     HTML (using search portal)
# @stable      yes (HTML can change)
# @parse       url, title, content, price, shipping, source

from lxml import html
from searx.engines.xpath import extract_text
from searx.url_utils import quote

categories = ['shopping']
paging = True

url = 'https://www.ebay.com'
search_url = url + '/sch/i.html?_nkw={query}&_pgn={pageno}'

results_xpath = '//li[contains(@class, "lvresult")]'
url_xpath = './h3[@class="lvtitle"]/a/@href'
title_xpath = './h3[@class="lvtitle"]/a/text()'
content_xpath = './div[@class="lvsubtitle"]/text()'
price_xpath = './ul[@class="lvprices left space-zero"]/li[@class="lvprice prc"][1]/span[@class="bold"]'
shipping_xpath = './ul[@class="lvprices left space-zero"]/li[@class="lvshipping"]/span[@class="ship"]/span/span/text()'
source_country_xpath = './ul[contains(@class, "lvdetails")]/li[1]'
thumbnail_xpath = './div[contains(@class, "lvpic")]//img/@src'


def request(query, params):
    params['url'] = search_url.format(query=quote(query), pageno=params['pageno'])
    return params


def response(resp):
    results = []

    dom = html.fromstring(resp.text)
    results_dom = dom.xpath(results_xpath)
    if not results_dom:
        return []

    for result_dom in results_dom:
        url = extract_text(result_dom.xpath(url_xpath))
        title = extract_text(result_dom.xpath(title_xpath))
        content = extract_text(result_dom.xpath(content_xpath))
        price = extract_text(result_dom.xpath(price_xpath))
        shipping = extract_text(result_dom.xpath(shipping_xpath))
        source_country = extract_text(result_dom.xpath(source_country_xpath))
        thumbnail = extract_text(result_dom.xpath(thumbnail_xpath))

        results.append({
            'url': url, 
            'title': title, 
            'content': content, 
            'price': price, 
            'shipping': shipping, 
            'source_country': source_country, 
            'thumbnail': thumbnail, 
            'template': 'products.html',

        })

    return results
